#ifndef _DPF_H
#define _DPF_H

#include <arpa/inet.h>

#ifdef __cplusplus
extern "C" {
#endif

/* DPF API */
/* Initialize DPF. This function must be called before any other DPF function. To
 * support the cases that applications are simply linked with eGBC without any
 * rewriting of applications, each DPF function calls this function with default
 * arguments if it has never called. These default arguments are configurable through
 * environment variables except 'password'
 */
// @args:
//   - debug_file_path: the full pathname of the file that DPF log messages go.
//       DPF_DEBUG_PATH environment variable is used if caller passes NULL or this
//       function gets called implicitly
//   - debug_level: "basic", "network", or "fulldebug". "basic" logs the least
//       information and "fulldebug" the most. DPF_DEBUG_LEVEL environment
//       variable is used if the caller passes NULL or this function gets called
//       implicitly
//   - max_debug_file_size: DPF_LOG_MAXSIZE variable is used if negative value is
//       passed or this function gets called implicitly
void DPF_init(char *debug_file_path, char *debug_level, int max_debug_file_size);
int DPF_socket(int domain, int type, int protocol);
int DPF_bind(int fd, struct sockaddr *my_addr, socklen_t addrlen);
int DPF_listen(int fd, int backlog);
int DPF_connect(int fd, const struct sockaddr *serv_addr, socklen_t addrlen);
int DPF_select(int mxfd, fd_set *rdfds, fd_set *wrfds, fd_set *exfds,
        struct timeval *timeout);
int DPF_accept(int fd, struct sockaddr * peer, socklen_t *addrlen);
int DPF_recv(int fd, void *msg, size_t len, int flags);
int DPF_recvfrom(int fd, void *buf, size_t size, int flags,
        struct sockaddr *from, socklen_t *fromlen);
int DPF_read(int fd, void *msg, size_t len);
int DPF_send(int fd, const void *msg, size_t len, int flags);
int DPF_write(int fd, const void *msg, size_t len);
int DPF_sendto(int fd, const void *msg, size_t len, int flags,
        const struct sockaddr *to, socklen_t addrlen);
int DPF_dup(int fd);
int DPF_dup2(int fd, int newfd);
int DPF_getsockname(int sockfd, struct sockaddr *name, socklen_t *namelen);
int DPF_getsockopt(int fd, int level, int optname, void *opt_val, socklen_t *optlen);
int DPF_fcntl(int fd, int cmd, void *arg);
int DPF_inheritFrom();
int DPF_inheritTo();
pid_t DPF_fork(void);
int DPF_execv(const char *path, char *const argv[]);
int DPF_execl(const char *path, const char *arg, ...);
int DPF_execve(const char *path, char *const argv [], char *const envp[]);
int DPF_close(int fd);
void DPF_cleanup(void);

#ifdef __cplusplus
}
#endif

#endif
